pub struct ProductAdsPaymentEvent {
pub posted_date: Option<String>,
pub transaction_type: Option<String>,
pub invoice_id: Option<String>,
pub base_value: Option<Box<Currency>>,
pub tax_value: Option<Box<Currency>>,
pub transaction_value: Option<Box<Currency>>,
}Expand description
ProductAdsPaymentEvent : A Sponsored Products payment event.
Fields
posted_date: Option<String>transaction_type: Option<String>Indicates if the transaction is for a charge or a refund. Possible values: * charge - Charge * refund - Refund
invoice_id: Option<String>Identifier for the invoice that the transaction appears in.
base_value: Option<Box<Currency>>tax_value: Option<Box<Currency>>transaction_value: Option<Box<Currency>>Implementations
sourceimpl ProductAdsPaymentEvent
impl ProductAdsPaymentEvent
sourcepub fn new() -> ProductAdsPaymentEvent
pub fn new() -> ProductAdsPaymentEvent
A Sponsored Products payment event.